#
# spec file for package python-azure-servicebus
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-azure-servicebus
Version:        7.14.2
Release:        1.1
Summary:        Microsoft Azure Service Bus Runtime Client Library
License:        Apache-2.0
Group:          Development/Languages/Python
URL:            https://github.com/Azure/azure-sdk-for-python
Source:         https://files.pythonhosted.org/packages/source/a/azure_servicebus/azure_servicebus-%{version}.tar.gz
BuildRequires:  %{python_module azure-nspkg >= 3.0.0}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-azure-nspkg >= 3.0.0
Requires:       python-isodate >= 0.6.0
Requires:       python-typing_extensions >= 4.6.0
Requires:       (python-azure-core >= 1.28.0 with python-azure-core < 2.0.0)
Conflicts:      python-azure-sdk <= 2.0.0
%if 0%{?sle_version} >= 150400
Obsoletes:      python3-azure-servicebus < 7.11.4
%endif
BuildArch:      noarch

%python_subpackages

%description
This is the Microsoft Azure Service Bus Client Library.
This package has been tested with Python 2.7, 3.4, 3.5, 3.6 and 3.7.

Microsoft Azure Service Bus supports a set of cloud-based, message-oriented
middleware technologies including reliable message queuing and durable
publish/subscribe messaging.

%prep
%setup -q -n azure_servicebus-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}
%{python_expand # delete common files
rm -rf %{buildroot}%{$python_sitelib}/azure/__init__.*
rm -rf %{buildroot}%{$python_sitelib}/azure/__pycache__
}

%files %{python_files}
%doc CHANGELOG.md README.md
%license LICENSE
%{python_sitelib}/azure/servicebus
%{python_sitelib}/azure_servicebus-*.dist-info

%changelog
* Thu Apr 10 2025 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 7.14.2
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
* Tue Mar 18 2025 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 7.14.1
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
* Mon Feb 17 2025 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 7.14.0
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
* Wed Nov 13 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 7.13.0
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
* Fri Sep 20 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 7.12.3
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
- Adjust upstream source name in spec file
- Drop extra LICENSE.txt as upstream now ships its own
- Rename LICENSE.txt to LICENSE in %%files section
* Mon May 13 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 7.12.2
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
- Update Requires from setup.py
* Tue Apr  9 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 7.12.1
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
- Update Requires from setup.py
* Thu Apr  4 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Switch package to modern Python Stack on SLE-15
  + Use Python 3.11 on SLE-15 by default
  + Add Obsoletes for old python3 package on SLE-15
  + Drop support for older Python versions
- Switch build system from setuptools to pyproject.toml
  + Add python-pip and python-wheel to BuildRequires
  + Replace %%python_build with %%pyproject_wheel
  + Replace %%python_install with %%pyproject_install
  + Update name for dist directory in %%files section
- Drop setting default file attributes in %%files section
- Use modern RPM macros to express version dependencies
* Tue Nov 14 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 7.11.4
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
* Thu Oct 12 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 7.11.3
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
* Fri Sep 15 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 7.11.2
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
- Remove unzip package from BuildRequires
- Switch source archive format to TAR.GZ
* Thu Jul 13 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 7.11.1
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
* Mon Jul  3 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 7.11.0
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
* Wed May 10 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 7.10.0
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
- Update Requires from setup.py
* Mon Apr 17 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 7.9.0
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
- Update Requires from setup.py
* Fri Mar 10 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 7.8.3
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
* Fri Jan 13 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 7.8.2
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
- Update Requires from setup.py
* Wed Oct 12 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 7.8.1
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
* Fri Jul  8 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 7.8.0
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
- Update Requires from setup.py
* Wed Jun  8 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 7.7.0
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
* Tue Apr 12 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 7.6.1
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
* Fri Feb 11 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 7.6.0
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
* Thu Jan 13 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 7.5.0
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
- Update Requires from setup.py
* Wed Nov 10 2021 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 7.4.0
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
* Thu Oct  7 2021 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 7.3.4
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
- Update Requires from setup.py
* Thu Sep  9 2021 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 7.3.3
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
* Thu Jul 22 2021 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 7.3.1
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
- Update Requires from setup.py
* Thu Jun 10 2021 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 7.3.0
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
- Update Requires from setup.py
* Fri May  7 2021 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 7.1.1
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
- Update Requires from setup.py
* Tue Mar 23 2021 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 7.1.0
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
- Update Requires from setup.py
* Tue Jan 19 2021 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 7.0.1
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
- Update Requires from setup.py
* Thu Nov 26 2020 Robert Schweikert <rjschwei@suse.com>
- Only build Python3 flavors for distributions 15 and greater
* Fri Aug 28 2020 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 0.50.3
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
- Rename HISTORY.rst to CHANGELOG.md in %%files section
- Rename README.rst to README.md in %%files section
- Update Requires from setup.py
* Thu Jan 23 2020 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 0.50.2
  + For detailed information about changes see the
    HISTORY.txt file provided with this package
- Update %%description from README.rst
- Update Requires from setup.py
* Fri Oct  4 2019 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 0.50.1
  + For detailed information about changes see the
    HISTORY.txt file provided with this package
- Drop patches to support older versions of setuptools as
  SLE-12 is now shipping with a recent enough version
  + as_drop-compatible-releases-operator.patch
  + as_drop-extras-require.patch
* Mon Apr 15 2019 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 0.50.0
  + For detailed information about changes see the
    HISTORY.txt file provided with this package
- Add patch to drop compatible releases operator from setup.py,
  required for SLES12 as the setuptools version is too old
  + as_drop-compatible-releases-operator.patch
- Add patch to drop extras_require field from setup.py,
  required for SLES12 as the setuptools version is too old
  + as_drop-extras-require.patch
- Bump minimum version for namespace packages
  to 3.0.0 in BuildRequires and Requires
- Remove python-devel package from BuildRequires
- Run fdupes to hardlink duplicate files
  + Add fdupes to BuildRequires
  + Add %%fdupes invocation to %%install
- Update BuildRequires and Requires from setup.py
* Thu Sep  6 2018 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Move LICENSE.txt from %%doc to %%license section
* Tue Jan 30 2018 adrian.glaubitz@suse.com
- Install HISTORY.rst into doc directory
* Thu Oct  5 2017 adrian.glaubitz@suse.com
- Remove versioning for namespace packages in Requires
- Add namespace packages to BuildRequires
- Remove namespace files in %%install target
- Explicitly specify Python files of the package in %%files
* Fri Jul 14 2017 adrian.glaubitz@suse.com
- Add python-azure-nspkg to Requires
* Wed Jun 28 2017 adrian.glaubitz@suse.com
- Initial build
  + Version 0.21.1
